@@ -27,10 +27,21 @@ topn        = function(vec, n=6L, decreasing=TRUE, hasna=TRUE,index=TRUE) if(ind
 uniqLen     = function(x) .Call(CdupLenR, x)
 vswitch     = function(x, values, outputs, default=NULL, nThread=getOption("kit.nThread"), checkEnc = TRUE) .Call(CvswitchR, x, values, outputs, default, nThread, checkEnc)
 
-.onAttach   = function(libname, pkgname) packageStartupMessage(paste0("Attaching kit 0.0.15 (OPENMP ",if(.Call(CompEnabledR)) "enabled" else "disabled"," using 1 thread)"))
-.onLoad     = function(libname, pkgname) options("kit.nThread"=1L)   #nocov
 .onUnload   = function(libpath) library.dynam.unload("kit", libpath) #nocov
 
+.onAttach   = function(libname, pkgname) { #nocov
+  omp = if(.Call(CompEnabledR)) "enabled" else "disabled" #nocov
+  nth = getOption("kit.nThread") #nocov
+  thd = if (nth > 1L) " threads)" else " thread)" #nocov
+  packageStartupMessage(paste0("Attaching kit 0.0.17 (OPENMP ",omp," using ",nth,thd)) #nocov
+} #nocov
+
+.onLoad     = function(libname, pkgname) { #nocov
+  if (!("kit.nThread" %in% names(options()))) { #nocov
+    options("kit.nThread"=1L) #nocov
+  } #nocov
+} #nocov
+
 pcount      = function(..., value) {
   if(is.na(value[1])) {
     .Call(CpcountNAR, if (...length() == 1L && is.list(..1)) ..1 else list(...))
