@@ -1,6 +1,6 @@
 /*
  * kit : Useful R Functions Implemented in C
- * Copyright (C) 2020-2021  Morgan Jacob
+ * Copyright (C) 2020-2024  Morgan Jacob
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -526,7 +526,7 @@ SEXP nifR(SEXP na, SEXP rho, SEXP args) {
   return ans;
 }
 
-SEXP nifInternalR(SEXP na, SEXP rho, SEXP args) { // # nocov start
+SEXP nifInternalR(SEXP na, SEXP args) { // # nocov start
   R_len_t n=length(args);
   if (n % 2) {
     error("Received %d inputs; please supply an even number of arguments in ... "
